Structs
Enums
Functions
- execute
- Execute the CLI command with the given arguments.
- handle_
find_ replace - Handle find and replace operations within environment variable values.
- handle_
profile - Handle profile-related commands.
- handle_
project - Handle project-related commands.
- handle_
rename - Handle rename command to rename environment variables using patterns.
- handle_
replace - Handle replace command to replace environment variable values using patterns.
- handle_
snapshot - Handle snapshot-related commands.
- handle_
watch - Handle file watching and synchronization operations.