Module cli

Module cli 

Structs

Cli
FindReplaceArgs
ProfileArgs
ProjectArgs
RenameArgs
ReplaceArgs
SnapshotArgs

Enums

Commands
PathAction
ProfileCommands
ProjectCommands
SnapshotCommands

Functions

execute
Execute the CLI command with the given arguments.
handle_find_replace
Handle find and replace operations within environment variable values.
handle_profile
Handle profile-related commands.
handle_project
Handle project-related commands.
handle_rename
Handle rename command to rename environment variables using patterns.
handle_replace
Handle replace command to replace environment variable values using patterns.
handle_snapshot
Handle snapshot-related commands.